#include <panel-applet.h>
#include "mini-commander_applet.h"

extern GtkWidget *label_message;

void init_message_label(MCData *mcdata);
void show_message(gchar *message);
